Crate buildkit_rs_ignore

Crate buildkit_rs_ignore 

Enums

Error

Functions

read_ignore_to_list
Read all reads an ignore file and returns the list of file patterns to ignore. Note this will trim whitespace from each line as well as use Rust’s PathBuf to get the cleanest path for each.