Enums
Functions
- read_
ignore_ to_ list - Read all reads an ignore file and returns the list of file patterns
to ignore. Note this will trim whitespace from each line as well
as use Rust’s
PathBufto get the cleanest path for each.
PathBuf to get the cleanest path for each.